<?php

namespace Crm\Advertisement\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Crm\Advertisement\Events\AdvertisementAction as AdvertisementActionEvent;
use Crm\Advertisement\Notifications\AdvertisementAction as AdvertisementActionNotification;
use Litepie\Actions\Concerns\AsAction;

class AdvertisementAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the AdvertisementActionEvent.
     *
     * @param   AdvertisementActionEvent  $event
     * @return mixed
     */
    public function handle(AdvertisementActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $advertisement.
     *
     * @param   AdvertisementActionEvent  $event
     * @return void
     */
    public function create(AdvertisementActionEvent $event)
    {
        $client = $event->advertisement->client;
        Notification::send($client, new AdvertisementActionNotification($event));
    }

    /**
     * Handle the AdvertisementActionEvent as a listener.
     *
     * @param   AdvertisementActionEvent  $event
     * @return mixed
     */
    public function asListener(AdvertisementActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   AdvertisementActionEvent  $event
     * @return bool
     */
    private function isAllowed(AdvertisementActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
