<?php

namespace Crm\Advertisement\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Crm\Advertisement\Models\Advertisement;

class AdvertisementPolicy
{


    /**
     * Determine if the given user can view the advertisement.
     *
     * @param Authenticatable $user
     * @param Advertisement $advertisement
     *
     * @return bool
     */
    public function view(Authenticatable $user, Advertisement $advertisement)
    {
        if ($authUser->canDo('advertisement.advertisement.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $advertisement->is_owner;
    }

    /**
     * Determine if the given user can create a advertisement.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('advertisement.advertisement.create');
    }

    /**
     * Determine if the given user can update the given advertisement.
     *
     * @param Authenticatable $user
     * @param Advertisement $advertisement
     *
     * @return bool
     */
    public function update(Authenticatable $user, Advertisement $advertisement)
    {
        if ($user->canDo('advertisement.advertisement.edit') && $user->isAdmin()) {
            return true;
        }

        return $advertisement->is_owner;
    }

    /**
     * Determine if the given user can delete the given advertisement.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Advertisement $advertisement)
    {
        return $advertisement->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
